// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KONTACTINTERFACE_VERSION_H
#define KONTACTINTERFACE_VERSION_H

#define KONTACTINTERFACE_VERSION_STRING "5.21.1"
#define KONTACTINTERFACE_VERSION_MAJOR 5
#define KONTACTINTERFACE_VERSION_MINOR 21
#define KONTACTINTERFACE_VERSION_PATCH 1
#define KONTACTINTERFACE_VERSION ((5<<16)|(21<<8)|(1))

#endif
